##Below is the code used to generate statistical results in Koski et al. 2020, Current Biology
##Predictions 1 and 2 from the manuscript are addressed by two separate models in the 'SAS CODE' section. 
##Prediction 3 from the manuscript was addressed by models in the 'R CODE' section. 


##SAS CODE
## input data is "Koski et al. Current Biology Data.xlsx" 'Spatiotemp and Clim Mod Data' tab
##  spatiotemporal model of variation in UVP

proc mixed data=all plots=all;
class Symmetry Species Hemisphere;
model asinuvp= symmetry|abslat hemisphere|symmetry|altitude symmetry|Year Year|symmetry(species)/solution;
random hemisphere;
run;

##climatic model of variation in UVP

proc glm data=all plots=all;
class Symmetry Species Hemisphere;
model asinuvp= symmetry(species) symmetry|avg_ozone avg_temp  /solution;
random hemisphere;
run;


## R CODE


require(car)
require(ape)
require(geiger)
require(phytools)
require(nlme)


## temporal change model


## Get standardized effects of year on UVP, ozone, and temperature for each species

#split dataset by species
spl <- with(alldata, split(alldata, list(Species=Species)))

#extract year effect on UVP
coefLM.uvp <- function(x) {
   coef(lm(scale(UVP)~scale(Latitude)+scale(Longitude)+scale(altitude)+scale(Year_), data = x))[5]
 }

coefs.uvp <- sapply(spl, coefLM.uvp)

#extract year effect on ozone
coefLM.ozone <- function(x) {
   coef(lm(scale(avg_ozone)~scale(Latitude)+scale(Longitude)+scale(altitude)+scale(Year_), data = x))[5]
 }
 
coefs.ozone <- sapply(spl, coefLM.ozone)

#extract year effect on temperature
coefLM.temp <- function(x) {
   coef(lm(scale(avg_temp)~scale(Latitude)+scale(Longitude)+scale(altitude)+scale(Year_), data = x))[5]
 }

coefs.temp <- sapply(spl, coefLM.temp)

## model change in UVP as a function of symmetry, habitat type, life history, change in temperature and change in ozone. 

## input data is "Koski et al. Current Biology Data.xlsx" 'Climate Change Mod Data' tab


mod.change <- glm(uvp~symm*temp+symm*ozone+lifehist+habitat, weight=samples)

Anova(mod.change, type=3)


# Run phylogenetically-controlled model

tree<-read.nexus('bushytree.nex')

pglsModel <- gls(uvp~symm*temp+symm*ozone+lifehist+habitat, correlation = corBrownian(phy = tree),
     data = df, weights=~samples, method = "ML")

Anova(pglsModel, type=3)

